@@ -4,7 +4,7 @@ from contextlib import contextmanager
 from os import linesep
 from collections import namedtuple
 from sys import exc_info
-from typing import Callable, Union, Type, Generator, List, Any
+from typing import Callable, Optional, Union, Type, Generator, List, Any
 
 ViewInfo = namedtuple('ViewInfo', ['view', 'line'])
 
@@ -12,12 +12,12 @@ ViewInfo = namedtuple('ViewInfo', ['view', 'line'])
 class PyViewsError(Exception):
     """Base error class for custom exceptions"""
 
-    def __init__(self, message: str = '', view_info: ViewInfo = None):
+    def __init__(self, message: str = '', view_info: Optional[ViewInfo] = None):
         super().__init__(linesep)
         self.infos: List[str] = []
         self.view_infos: List[ViewInfo] = []
         # noinspection PyTypeChecker
-        self.cause_error: BaseException = None
+        self.cause_error: Optional[BaseException] = None
         self.message = message
         if view_info:
             self.add_view_info(view_info)
@@ -74,7 +74,7 @@ class PyViewsError(Exception):
 
 @contextmanager
 def error_handling(error_to_raise: Union[PyViewsError, Type[PyViewsError]],
-                   add_error_info: Callable[[PyViewsError], None] = None):
+                   add_error_info: Optional[Callable[[PyViewsError], None]] = None):
     """handles error and raises PyViewsError with custom error info"""
     add_error_info = add_error_info if add_error_info is not None else _do_nothing
     try:
