@@ -2,8 +2,9 @@
 
 import ast
 from collections import namedtuple
+from functools import partial
 from types import CodeType
-from typing import List, Callable, Any, Iterator, NamedTuple, Union
+from typing import List, Callable, Any, NamedTuple, Union, Set, Dict, Tuple
 
 from injectool import dependency
 
@@ -12,11 +13,48 @@ from pyviews.expression.error import ExpressionError
 
 _COMPILATION_CACHE = {}
 _CacheItem = namedtuple('CacheItem', ['compiled_code', 'tree'])
+_AST_CLASSES = {ast.Name, ast.Attribute, ast.Subscript}
+
+ROOT = 'root'
+ENTRY = 'entry'
+ATTRIBUTE = 'attribute'
+INDEX = 'index'
+
+_TYPES = {
+    ast.Name: ENTRY,
+    ast.Attribute: ATTRIBUTE,
+    ast.Subscript: INDEX
+}
+
+
+def _get_index_value(ast_node: ast.Subscript):
+    ast_node = ast_node.slice.value if isinstance(ast_node.slice, ast.Index) else ast_node.slice
+    if isinstance(ast_node, ast.Constant):
+        return ast_node.value
+    if isinstance(ast_node, ast.Num):
+        return ast_node.n
+    return _get_attr_expression(ast_node)
+
+
+def _get_attr_expression(ast_node: Union[ast.Name, ast.Attribute]) -> 'Expression':
+    result = ''
+    while isinstance(ast_node, ast.Attribute):
+        result = f'.{ast_node.attr}{result}'
+        ast_node = ast_node.value
+    return Expression(f'{ast_node.id}{result}')
+
+
+_KEYS = {
+    ast.Name: lambda n: n.id,
+    ast.Attribute: lambda n: n.attr,
+    ast.Subscript: _get_index_value
+}
 
 
 class ObjectNode(NamedTuple):
-    """Entry of object in expression"""
+    """Root entry in expression"""
     key: str
+    type: str
     children: List['ObjectNode']
 
 
@@ -52,40 +90,37 @@ class Expression:
 
     def _build_object_tree(self) -> ObjectNode:
         ast_root = ast.parse(self._code)
-        ast_nodes = list(ast.walk(ast_root))
-        children = list(self._get_children(ast_nodes, self._is_child))
-        return ObjectNode('root', children)
+        ast_nodes = {n for n in ast.walk(ast_root) if n.__class__ in _AST_CLASSES}
+        return ObjectNode('root', ROOT, self._create_nodes(ast_nodes, self._is_name))
 
     @staticmethod
-    def _is_child(ast_node: ast.AST) -> bool:
+    def _is_name(ast_node: ast.AST) -> bool:
         return isinstance(ast_node, ast.Name)
 
-    def _get_children(self, ast_nodes: List[ast.AST], is_child: Callable[[ast.AST], bool]) \
-            -> Iterator[ObjectNode]:
-        ast_children = [n for n in ast_nodes if is_child(n)]
+    def _create_nodes(self, ast_nodes: Set[ast.AST], node_filter: Callable[[ast.AST], bool]) \
+            -> List[ObjectNode]:
+        ast_nodes_to_create = {n for n in ast_nodes if node_filter(n)}
+        ast_nodes = ast_nodes.difference(ast_nodes_to_create)
 
-        grouped = self._group_by_key(ast_children)
-
-        for key, key_nodes in grouped.items():
-            children = self._get_children(ast_nodes,
-                                          lambda n, nds=key_nodes: self._is_attribute(n, nds))
-            yield ObjectNode(key, list(children))
+        grouped = self._group(ast_nodes_to_create).items()
+        return [ObjectNode(key, node_type,
+                           self._create_nodes(ast_nodes, partial(self._is_child, nodes)))
+                for key, (nodes, node_type) in grouped]
 
     @staticmethod
-    def _is_attribute(ast_node: ast.AST, key_nodes: dict) -> bool:
-        return isinstance(ast_node, ast.Attribute) and ast_node.value in key_nodes
+    def _is_child(key_nodes: set, ast_node: ast.AST) -> bool:
+        return ast_node.value in key_nodes
 
     @staticmethod
-    def _group_by_key(ast_nodes) -> dict:
-        try:
-            grouped_by_id = {node.id: [] for node in ast_nodes}
-            for ast_child in ast_nodes:
-                grouped_by_id[ast_child.id].append(ast_child)
-        except AttributeError:
-            grouped_by_id = {node.attr: [] for node in ast_nodes}
-            for ast_child in ast_nodes:
-                grouped_by_id[ast_child.attr].append(ast_child)
-        return grouped_by_id
+    def _group(ast_nodes: Set[ast.AST]) -> Dict[str, Tuple[Set[ast.AST], str]]:
+        result = {}
+        for ast_node in ast_nodes:
+            key = _KEYS[ast_node.__class__](ast_node)
+            if key not in result:
+                result[key] = ({ast_node}, _TYPES[ast_node.__class__])
+            else:
+                result[key][0].add(ast_node)
+        return result
 
     def _store_to_cache(self):
         item = _CacheItem(self._compiled_code, self._object_tree)
